@@ -78,7 +78,7 @@ class Picacomic(CheckIn):
         sign_msg = self.sign(email=email, password=password)
         msg = [
             {"name": "帐号信息", "value": f"{email}"},
-            {"name": "签到状态", "value": f"{sign_msg}"},
+            {"name": "签到信息", "value": f"{sign_msg}"},
         ]
         msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
         return msg
