@@ -20,7 +20,7 @@ class Smzdm(CheckIn):
             current = session.get(url="https://zhiyou.smzdm.com/user/info/jsonp_get_current").json()
             if current["checkin"]["has_checkin"]:
                 msg = [
-                    {"name": "用户信息", "value": current.get("nickname", "")},
+                    {"name": "账号信息", "value": current.get("nickname", "")},
                     {"name": "目前积分", "value": current.get("point", "")},
                     {"name": "当前经验", "value": current.get("exp", "")},
                     {"name": "当前金币", "value": current.get("gold", "")},
@@ -32,7 +32,7 @@ class Smzdm(CheckIn):
             else:
                 response = session.get(url="https://zhiyou.smzdm.com/user/checkin/jsonp_checkin").json().get("data", {})
                 msg = [
-                    {"name": "用户信息", "value": current.get("nickname", "")},
+                    {"name": "账号信息", "value": current.get("nickname", "")},
                     {"name": "目前积分", "value": current.get("point", "")},
                     {"name": "增加积分", "value": current.get("add_point", "")},
                     {"name": "当前经验", "value": current.get("exp", "")},
@@ -43,7 +43,7 @@ class Smzdm(CheckIn):
                 ]
         except Exception as e:
             msg = [
-                {"name": "签到状态", "value": "签到失败"},
+                {"name": "签到信息", "value": "签到失败"},
                 {"name": "错误信息", "value": str(e)},
             ]
         return msg
