@@ -36,14 +36,14 @@ class WWW2NZZ(CheckIn):
         uid = uid[0] if uid else "未获取到 UID"
         if "您今天已经签到过了或者签到时间还未开始" in response.text:
             msg = [
-                {"name": "用户信息", "value": uid},
+                {"name": "账号信息", "value": uid},
                 {"name": "签到信息", "value": "您今天已经签到过了或者签到时间还未开始"},
             ]
         else:
             check_msg = re.findall(r"<div class=\"c\">(.*?)</div>", response.text, re.S)
             check_msg = check_msg[0].strip() if check_msg else "签到失败"
             msg = [
-                {"name": "用户信息", "value": uid},
+                {"name": "账号信息", "value": uid},
                 {"name": "签到信息", "value": check_msg},
             ]
         return msg
