@@ -35,14 +35,14 @@ class ZhiYoo(CheckIn):
         uid = uid[0] if uid else "未获取到 UID"
         if "今日已经签到" in response.text:
             msg = [
-                {"name": "用户信息", "value": uid},
+                {"name": "账号信息", "value": uid},
                 {"name": "签到信息", "value": "您今日已经签到，请明天再来！"},
             ]
         else:
             check_msg = re.findall(r"恭喜你签到成功!获得随机奖励 金币 (\d+) 元.", response.text, re.S)
             check_msg = check_msg[0].strip() if check_msg else "签到失败"
             msg = [
-                {"name": "用户信息", "value": uid},
+                {"name": "账号信息", "value": uid},
                 {"name": "签到信息", "value": f"恭喜你签到成功!获得随机奖励 金币 {check_msg} 元."},
             ]
         return msg
